==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/viking2/dialogs_pl.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")
dialogStr("Ta łódź musiała zatonąć dawno temu.")


dialogId("dr1-v-urcite", "font_big", "Definitely. It`s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")
dialogStr("Z pewnością. To jeden z najstarszych drakkarów. Sądząc po rzeźbieniach i zdobieniach, a także po kolorze wody, należał do dziadka Eryka Rudego.")


dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")
dialogStr("Albo do teścia Olafa Dzielnego.")


dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")
dialogStr("Albo prastryjka Lejfa Sprawnego.")


dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")
dialogStr("Ewentualnie do bratanicy Harolda Wielkiego.")


dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")
dialogStr("Lub do ciotki Snorra Odważnego.")


dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")
dialogStr("A może należał do Thorsona Twardego?")


dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it`s never too late to start a new life!")
dialogStr("A ja zawsze myślałem, że jestem kutrem Eryka Niegotowego... Lecz dziś poznałem prawdę. Nigdy nie jest za późno, by zacząć nowe życie.")


dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")
dialogStr("Biedny piesek.")


dialogId("dr-m-nedycha", "font_small", "Doesn't he seem to be breathing kind of strangely?")
dialogStr("Nie wydaje ci się, że jakoś dziwnie oddycha?")


dialogId("dr-v-napsa", "font_big", "For a dog under water I think he's doing rather well.")
dialogStr("Jak na psa pod wodą, całkiem sprawnie mu to idzie.")


dialogId("dr-v-nato", "font_big", "He doesn't look all that bad considering that he's been here for a few centuries.")
dialogStr("Nie wygląda najgorzej, jeśli wziąć pod uwagę, że jest tu od kilku stuleci.")


dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")
dialogStr("Cichaj!")


dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")
dialogStr("Zamkniesz się wreszcie?!")


dialogId("dr-8-nenechas", "font_viking8", "So, you`re not going to shut up, are you?")
dialogStr("Więc się nie zamkniesz?!")


dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")
dialogStr("Aaaaaa...")


dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")
dialogStr("Heheheheheh... Hahahahahaha... Hihihihihihi...")


dialogId("dr-5-srab1", "font_viking5", "Is it over?")
dialogStr("Już po wszystkim?")


dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")
dialogStr("Jesteśmy bezpieczni?")


dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")
dialogStr("Już po bitwie?")


dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")
dialogStr("Czy wróg już odpłynął?")


dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")
dialogStr("Czy wciąż walczymy?")


dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")
dialogStr("Szefie, jesteśmy już w Walhalli?")


dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")
dialogStr("Kiedy dotrzemy do Walhalli?")


dialogId("dr-1-aztambudem", "font_viking1", "I`ll let you know once we get there.")
dialogStr("Dam wam znać, gdy tam będziemy.")


dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")
dialogStr("Szefie, mogę skoczyć na stronę?")


dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")
dialogStr("Poczekaj, aż dotrzemy do Walhalli.")


dialogId("dr-2-netrva", "font_viking2", "Isn`t this journey to Valhalla taking a bit too long?")
dialogStr("Czy ta podróż nie trwa aby zbyt długo?")


dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")
dialogStr("Cierpliwość jest cechą prawdziwego wojownika.")


dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")
dialogStr("Czy do Walhalli to na pewno tędy?")


dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")
dialogStr("Wojownik musi ufać swojemu przywódcy!")


dialogId("dr-1-achjo", "font_viking1", "Ahhh, I`m in charge of a ship full of cowards.")
dialogStr("Ech, dowodzę statkiem pełnym tchórzy.")


dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")
dialogStr("Dlaczego przypadło mi dowodzić statkiem pełnych kretynów?")


dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I`ll go drown myself.")
dialogStr("Chichoczący kretyni, śliniący się pies... Idę się utopić.")


dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")
dialogStr("Prawdziwi wikingowie noszą brody.")


dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")
dialogStr("W-w-warkoczyki są dziś w m-m-modzie.")


dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")
dialogStr("A cóż to za moda? Warkoczyki... Śmiechu warte.")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("M-m-magazyn 'W-w-wikińska m-m-moda` zaleca blond w-w-warkoczyki do ciem-m-mnego hełm-m-mu i niebieskiej tarczy.")


dialogId("dr-3-stakovou", "font_viking3", "I simply don`t agree with such a fad.")
dialogStr("Ja tam takiej mody nie uznaję.")


dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")
dialogStr("Powinieneś trzymać się prawdziwie wikińskich tradycji.")


dialogId("dr-4-moderni", "font_viking4", "B-b-but I`m c-c-cool!")
dialogStr("Ale ja chcę być m-m-modny!")


dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")
dialogStr("Naw-w-wet Eryk Rudy m-m-miał w-w-warkoczyki!")


dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")
dialogStr("Nonsens. Miał brodę.")


dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")
dialogStr("Ale w-w-warkoczyki też!")


dialogId("dr-3-nemel", "font_viking3", "He did not. And that`s final.")
dialogStr("Nie miał i koniec.")


dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")
dialogStr("M-m-myślisz, że broda by m-m-mi bardziej pasow-w-wała?")


dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")
dialogStr("Oczywiście.")


dialogId("dr-4-budu", "font_viking4", "I`ll th-th-think it o-over.")
dialogStr("Przem-m-myślę to.")


dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")
dialogStr("Hmmm... Ehmmm... Hahmmm...")


dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")
dialogStr("Nie, w-w-warkoczyki są zdecydowanie lepsze.")


dialogId("dr-3-mladez", "font_viking3", "Today`s youth - absolutely unbelievable.")
dialogStr("Ta dzisiejsza młodzież... to się w głowie nie mieści.")


dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It`s unheard of.")
dialogStr("Chłop z warkoczykami. Kto to widział?!")


dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")
dialogStr("Wy, młodzi, myślicie, że wam wszystko uchodzi.")


dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")
dialogStr("W-w-w każdym razie wyglądam-m m-m-modnie...")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking2/dialogs_pl.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")
dialogStr("Ta łódź musiała zatonąć dawno temu.")


dialogId("dr1-v-urcite", "font_big", "Definitely. It’s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")
dialogStr("Z pewnością. To jeden z najstarszych drakkarów. Sądząc po rzeźbieniach i zdobieniach, a także po kolorze wody, należał do dziadka Eryka Rudego.")


dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")
dialogStr("Albo do teścia Olafa Dzielnego.")


dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")
dialogStr("Albo prastryjka Lejfa Sprawnego.")


dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")
dialogStr("Ewentualnie do bratanicy Harolda Wielkiego.")


dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")
dialogStr("Lub do ciotki Snorra Odważnego.")


dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")
dialogStr("A może należał do Thorsona Twardego?")


dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it’s never too late to start a new life!")
dialogStr("A ja zawsze myślałem, że jestem kutrem Eryka Niegotowego... Lecz dziś poznałem prawdę. Nigdy nie jest za późno, by zacząć nowe życie.")


dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")
dialogStr("Biedny piesek.")


dialogId("dr-m-nedycha", "font_small", "Doesn't he seem to be breathing kind of strangely?")
dialogStr("Nie wydaje ci się, że jakoś dziwnie oddycha?")


dialogId("dr-v-napsa", "font_big", "For a dog under water I think he's doing rather well.")
dialogStr("Jak na psa pod wodą, całkiem sprawnie mu to idzie.")


dialogId("dr-v-nato", "font_big", "He doesn't look all that bad considering that he's been here for a few centuries.")
dialogStr("Nie wygląda najgorzej, jeśli wziąć pod uwagę, że jest tu od kilku stuleci.")


dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")
dialogStr("Cichaj!")


dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")
dialogStr("Zamkniesz się wreszcie?!")


dialogId("dr-8-nenechas", "font_viking8", "So, you’re not going to shut up, are you?")
dialogStr("Więc się nie zamkniesz?!")


dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")
dialogStr("Aaaaaa...")


dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")
dialogStr("Heheheheheh... Hahahahahaha... Hihihihihihi...")


dialogId("dr-5-srab1", "font_viking5", "Is it over?")
dialogStr("Już po wszystkim?")


dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")
dialogStr("Jesteśmy bezpieczni?")


dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")
dialogStr("Już po bitwie?")


dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")
dialogStr("Czy wróg już odpłynął?")


dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")
dialogStr("Czy wciąż walczymy?")


dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")
dialogStr("Szefie, jesteśmy już w Walhalli?")


dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")
dialogStr("Kiedy dotrzemy do Walhalli?")


dialogId("dr-1-aztambudem", "font_viking1", "I’ll let you know once we get there.")
dialogStr("Dam wam znać, gdy tam będziemy.")


dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")
dialogStr("Szefie, mogę skoczyć na stronę?")


dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")
dialogStr("Poczekaj, aż dotrzemy do Walhalli.")


dialogId("dr-2-netrva", "font_viking2", "Isn’t this journey to Valhalla taking a bit too long?")
dialogStr("Czy ta podróż nie trwa aby zbyt długo?")


dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")
dialogStr("Cierpliwość jest cechą prawdziwego wojownika.")


dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")
dialogStr("Czy do Walhalli to na pewno tędy?")


dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")
dialogStr("Wojownik musi ufać swojemu przywódcy!")


dialogId("dr-1-achjo", "font_viking1", "Ahhh, I’m in charge of a ship full of cowards.")
dialogStr("Ech, dowodzę statkiem pełnym tchórzy.")


dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")
dialogStr("Dlaczego przypadło mi dowodzić statkiem pełnych kretynów?")


dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I’ll go drown myself.")
dialogStr("Chichoczący kretyni, śliniący się pies... Idę się utopić.")


dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")
dialogStr("Prawdziwi wikingowie noszą brody.")


dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")
dialogStr("W-w-warkoczyki są dziś w m-m-modzie.")


dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")
dialogStr("A cóż to za moda? Warkoczyki... Śmiechu warte.")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("M-m-magazyn 'W-w-wikińska m-m-moda’ zaleca blond w-w-warkoczyki do ciem-m-mnego hełm-m-mu i niebieskiej tarczy.")


dialogId("dr-3-stakovou", "font_viking3", "I simply don’t agree with such a fad.")
dialogStr("Ja tam takiej mody nie uznaję.")


dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")
dialogStr("Powinieneś trzymać się prawdziwie wikińskich tradycji.")


dialogId("dr-4-moderni", "font_viking4", "B-b-but I’m c-c-cool!")
dialogStr("Ale ja chcę być m-m-modny!")


dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")
dialogStr("Naw-w-wet Eryk Rudy m-m-miał w-w-warkoczyki!")


dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")
dialogStr("Nonsens. Miał brodę.")


dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")
dialogStr("Ale w-w-warkoczyki też!")


dialogId("dr-3-nemel", "font_viking3", "He did not. And that’s final.")
dialogStr("Nie miał i koniec.")


dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")
dialogStr("M-m-myślisz, że broda by m-m-mi bardziej pasow-w-wała?")


dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")
dialogStr("Oczywiście.")


dialogId("dr-4-budu", "font_viking4", "I’ll th-th-think it o-over.")
dialogStr("Przem-m-myślę to.")


dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")
dialogStr("Hmmm... Ehmmm... Hahmmm...")


dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")
dialogStr("Nie, w-w-warkoczyki są zdecydowanie lepsze.")


dialogId("dr-3-mladez", "font_viking3", "Today’s youth - absolutely unbelievable.")
dialogStr("Ta dzisiejsza młodzież... to się w głowie nie mieści.")


dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It’s unheard of.")
dialogStr("Chłop z warkoczykami. Kto to widział?!")


dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")
dialogStr("Wy, młodzi, myślicie, że wam wszystko uchodzi.")


dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")
dialogStr("W-w-w każdym razie wyglądam-m m-m-modnie...")
